VectorBytesEncoding

Enum VectorBytesEncoding 

pub enum VectorBytesEncoding {
    Raw,
    Hex,
}
How the input expression should be decoded before reinterpretation.

Variants



Raw

The expression already evaluates to a binary String/FixedString value.



Hex

The expression evaluates to a hex string and should be wrapped in unhex(...).